==> jm_basic_flutter-1.0.3.tar.gz: lib/utils/toast_util.dart <==
import 'package:bot_toast/bot_toast.dart';
import 'package:flutter/material.dart';

class ToastUtil {
  static show(String message, {Duration? duration}) {
    if (message.isNotEmpty) {
      BotToast.showText(
        duration: duration ?? Duration(seconds: 3),
        contentColor: Color(0xCC111111),
        contentPadding: EdgeInsets.all(16),
        textStyle: TextStyle(fontSize: 15, color: Colors.white),
        borderRadius: BorderRadius.all(Radius.circular(4)),
        text: message,
        align: Alignment.center,
        onlyOne: false,
      );
    }
  }

  // 透明遮罩loading
  static showTransparentLoading({bool clickClose = false, bool allowClick = false, bool ignoreContentClick = false}) {
    showLoading(clickClose: clickClose, allowClick: allowClick, ignoreContentClick: ignoreContentClick, backgroundColor: Colors.transparent);
  }

  ///[ignoreContentClick] 是否忽视ToastContext区域
  ///这个参数如果为true时,用户点击该ToastContext区域时,用户可以的点击事件可以正常到达到Page上
  ///换一句话说就是透明的(即便是Toast背景颜色不是透明),如果为false,则情况反之
  static showLoading({bool clickClose = false, bool allowClick = false, bool ignoreContentClick = false, Color backgroundColor = const Color(0x33000000)}) {
    BotToast.showCustomLoading(
      toastBuilder: (context) {
        return Container(
          padding: const EdgeInsets.all(20),
          decoration: const BoxDecoration(
            boxShadow: [
              BoxShadow(
                  color: Colors.black26, //阴影xy轴偏移量
                  blurRadius: 3, //阴影模糊程度
                  spreadRadius: 3 //阴影扩散程度
              )
            ],
            color: Colors.white,
            borderRadius: BorderRadius.all(
              Radius.circular(10),
            ),
          ),
          child: const CircularProgressIndicator(
            valueColor: AlwaysStoppedAnimation<Color>(Colors.blueAccent),
            backgroundColor: Colors.white,
          ),
        );
      },
      backgroundColor: backgroundColor,
      clickClose: clickClose,
      allowClick: allowClick,
      ignoreContentClick: ignoreContentClick,
      backButtonBehavior: BackButtonBehavior.ignore,
    );
  }

  static dismiss() {
    BotToast.closeAllLoading();
  }

  static void showError(String message, {Duration? duration}) {
    if (message.isNotEmpty) {
      BotToast.showText(
        duration: duration ?? Duration(seconds: 3),
        contentColor: Color(0xCC111111),
        contentPadding: EdgeInsets.all(16),
        textStyle: TextStyle(fontSize: 15, color: Colors.white),
        borderRadius: BorderRadius.all(Radius.circular(4)),
        text: message,
        align: Alignment.center,
        onlyOne: false,
      );
    }
  }
}

==> jm_basic_flutter-1.0.7.tar.gz: lib/utils/toast_util.dart <==
import 'package:bot_toast/bot_toast.dart';
import 'package:flutter/material.dart';

class ToastUtil {
  static show(String message, {Duration? duration}) {
    if (message.isNotEmpty) {
      BotToast.showText(
        duration: duration ?? Duration(seconds: 3),
        contentColor: Color(0xCC111111),
        contentPadding: EdgeInsets.all(16),
        textStyle: TextStyle(fontSize: 15, color: Colors.white),
        borderRadius: BorderRadius.all(Radius.circular(4)),
        text: message,
        align: Alignment.center,
        onlyOne: false,
      );
    }
  }

  // 透明遮罩loading
  static CancelFunc showTransparentLoading({bool clickClose = false, bool allowClick = false, bool ignoreContentClick = false}) {
    return showLoading(clickClose: clickClose, allowClick: allowClick, ignoreContentClick: ignoreContentClick, backgroundColor: Colors.transparent);
  }

  ///[ignoreContentClick] 是否忽视ToastContext区域
  ///这个参数如果为true时,用户点击该ToastContext区域时,用户可以的点击事件可以正常到达到Page上
  ///换一句话说就是透明的(即便是Toast背景颜色不是透明),如果为false,则情况反之
  static CancelFunc showLoading({
    bool clickClose = false,
    bool allowClick = false,
    bool ignoreContentClick = false,
    bool useSafeArea = true,
    Color backgroundColor = const Color(0x33000000),
    Duration? duration,
    Duration? animationDuration,
    Duration? animationReverseDuration,
    VoidCallback? onClose,
  }) {
    return BotToast.showCustomLoading(
      toastBuilder: (context) {
        return Container(
          padding: const EdgeInsets.all(20),
          decoration: const BoxDecoration(
            boxShadow: [
              BoxShadow(
                  color: Colors.black26, //阴影xy轴偏移量
                  blurRadius: 3, //阴影模糊程度
                  spreadRadius: 3 //阴影扩散程度
              )
            ],
            color: Colors.white,
            borderRadius: BorderRadius.all(
              Radius.circular(10),
            ),
          ),
          child: const CircularProgressIndicator(
            valueColor: AlwaysStoppedAnimation<Color>(Colors.blueAccent),
            backgroundColor: Colors.white,
          ),
        );
      },
      backgroundColor: backgroundColor,
      clickClose: clickClose,
      allowClick: allowClick,
      ignoreContentClick: ignoreContentClick,
      useSafeArea: useSafeArea,
      backButtonBehavior: BackButtonBehavior.ignore,
      duration: duration,
      animationDuration: animationDuration,
      animationReverseDuration: animationReverseDuration,
      onClose: onClose,
    );
  }

  static dismiss() {
    BotToast.closeAllLoading();
  }

  static void showError(String message, {Duration? duration}) {
    if (message.isNotEmpty) {
      BotToast.showText(
        duration: duration ?? Duration(seconds: 3),
        contentColor: Color(0xCC111111),
        contentPadding: EdgeInsets.all(16),
        textStyle: TextStyle(fontSize: 15, color: Colors.white),
        borderRadius: BorderRadius.all(Radius.circular(4)),
        text: message,
        align: Alignment.center,
        onlyOne: false,
      );
    }
  }
}
